No longer used
diff --git a/commons-jcs-core/src/main/java/org/apache/commons/jcs3/engine/CacheGroup.java b/commons-jcs-core/src/main/java/org/apache/commons/jcs3/engine/CacheGroup.java
index 64fb357..0c79706 100644
--- a/commons-jcs-core/src/main/java/org/apache/commons/jcs3/engine/CacheGroup.java
+++ b/commons-jcs-core/src/main/java/org/apache/commons/jcs3/engine/CacheGroup.java
@@ -22,9 +22,10 @@
 import org.apache.commons.jcs3.engine.behavior.IElementAttributes;
 
 /**
  * Holder for attributes specific to a group. The grouping functionality is on
  * the way out.
  */
+@Deprecated
 public class CacheGroup
 {
     /** Element configuration. */
@@ -47,9 +48,9 @@
     }
 
     /**
-     * Gets the attrributes attribute of the CacheGroup object
+     * Gets the attributes attribute of the CacheGroup object
      * <p>
-     * @return The attrributes value
+     * @return The attributes value
      */
     public IElementAttributes getElementAttrributes()
     {
@@ -22,9 +22,10 @@
 
 /**
- * Holder for attributes specific to a group. The grouping functionality is on
- * the way out.
+ * Holder for attributes specific to a group.
+ * @deprecated The grouping functionality is on the way out.
  */